"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const getProtoData_1 = require("../utils/getProtoData");
function mapPropsOrDocToDocument({ fields }, data) {
    if (typeof data === 'string') {
        return {};
    }
    return fields.reduce((props, { key, docKey }) => {
        if (!(key in data) && !(docKey in data)) {
            return props;
        }
        if (key in data && docKey in data && key !== docKey) {
            throw new Error(`Both '${key}' and '${docKey}' exist on ${data}`);
        }
        return Object.assign({}, props, {
            [docKey]: key in data ? data[key] : data[docKey]
        });
    }, {});
}
/**
 * This decorator is used to mark classes that will be an entity, a document
 * This function, by extending the constructor and defining this.sloth property
 * effectively allows the usage of other property decorators
 * @param name The database name for this entity
 * @typeparam S The database schema
 */
function SlothEntity(name) {
    return (constructor) => {
        const data = getProtoData_1.default(constructor.prototype, true);
        data.name = name;
        const BaseEntity = constructor;
        return class WrappedEntity extends BaseEntity {
            constructor(factory, idOrProps) {
                super(factory, idOrProps);
                this.sloth.props = mapPropsOrDocToDocument(getProtoData_1.default(this), idOrProps);
            }
        };
    };
}
exports.default = SlothEntity;
//# sourceMappingURL=SlothEntity.js.map