"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const getProtoData_1 = require("../utils/getProtoData");
const SlothView_1 = require("./SlothView");
/**
 * Creates an index for a field. It's a view function that simply emits
 * the document key
 *
 * @see [[SlothDatabase.queryDocs]]
 * @export
 * @template S
 * @param {(doc: S, emit: Function) => void} fn the view function, as arrow or es5 function
 * @param {string} [docId='views'] the _design document identifier
 * @param {string} [viewId] the view identifier, default by_<property name>
 * @returns the decorator to apply on the field
 */
function SlothIndex(viewId, docId) {
    return (target, key) => {
        const field = getProtoData_1.default(target).fields.find(field => field.key === key);
        if (!field) {
            throw new Error('Please use SlothIndex on top of a SlothField');
        }
        SlothView_1.default(new Function('doc', 'emit', `emit(doc['${field.docKey}'].toString());`), viewId, docId)(target, key);
    };
}
exports.default = SlothIndex;
//# sourceMappingURL=SlothIndex.js.map