"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const getProtoData_1 = require("../utils/getProtoData");
/**
 * Creates a view for a field. This function does not modify the
 * behavior of the current field, hence requires another decorator
 * such as SlothURI or SlothField.  The view  will be created by the SlothDatabase
 *
 * @export
 * @template S
 * @param {(doc: S, emit: Function) => void} fn the view function, as arrow or es5 function
 * @param {string} [docId='views'] the _design document identifier
 * @param {string} [viewId] the view identifier, default by_<property name>
 * @returns the decorator to apply on the field
 */
function SlothView(fn, viewId, docId = 'views') {
    return (target, key) => {
        const desc = Reflect.getOwnPropertyDescriptor(target, key);
        if (desc) {
            if (!desc.get && !desc.set) {
                throw new Error('Required SlothView on top of another decorator');
            }
        }
        const fun = `function (__doc) { 
      (${fn.toString()})(__doc, emit);
    }`;
        const { views, fields } = getProtoData_1.default(target, true);
        const field = fields.find(field => field.key === key);
        if (!field) {
            throw new Error('Required SlothView on top of a SlothField');
        }
        views.push({
            id: docId,
            name: viewId || `by_${field.docKey}`,
            function: fn,
            code: fun
        });
    };
}
exports.default = SlothView;
//# sourceMappingURL=SlothView.js.map