/**
 * SlothField decorator is used to mark a specific class property
 * as a document key. This introduces a few behaviors:
 *  - setting the value in the constructor (or directly alongside declaration)
 *    will set its default value
 *  - mutating the value will update it in updatedProps
 *  - accessing the value will first look into updatedProps, then props and then default values
 * @typeparam T the value type
 * @param docKeyName specifies the document key name, default to prop key name
 */
export default function SlothField<T>(docKeyName?: string): (this: any, target: object, key: string) => void;
