import PouchFactory from './PouchFactory';
import { RelationDescriptor } from './relationDescriptors';
/**
 * Base abstract entity, for all entitoies
 * The generic parameter S is the schema of the document
 * @typeparam S the document schema
 */
export default class BaseEntity<S extends {
    _id: string;
}> {
    _id: string;
    private sloth;
    constructor(factory: PouchFactory<S>, idOrProps: Partial<S> | string);
    /**
     * Returns whether this document hhas unsaved updated properties
     */
    isDirty(): boolean;
    /**
     * Returns a list of props following the entity schema
     */
    getProps(): S;
    /**
     * Returns a list of props mapped with docKey
     */
    getDocument(): any;
    /**
     * Saves document to database. If the document doesn't exist,
     * create it. If it exists, update it. If the _id was changed
     * (due to props changing), remove to old document and create a new one
     *
     * @returns a Promise resolving into document props
     *   - If the document was updated, the _rev prop would be defined
     *     and start with an index greater than 1
     *   - If the document was created, the _rev prop would be defined
     *     and start with 1
     *   - If the document was not updated, because it is not dirty,
     *     then no _rev property is returned
     */
    save(): Promise<S & {
        _rev?: string;
    }>;
    /**
     * Returns whether the specified document exists in database
     * Please note that this does not compare documents
     */
    exists(): Promise<boolean>;
    /**
     * Remove a document from the database
     * @returns a Promise that resolves into a boolean, true if document was removed,
     *          false if the document doesn't have a docId in its slothdata
     */
    remove(): Promise<boolean>;
    /**
     * @private
     */
    removeRelations(): Promise<void>;
    protected getProp(key: string): any;
    protected getRelationDescriptor(keyName: keyof S): RelationDescriptor & {
        key: string;
    };
    protected getRelationEntity(keyName: keyof S): Promise<any>;
    private removeEntityRelation(rel);
}
